==> qgis_0.8.0.orig.tar.gz: qgis-0.8.0/src/core/qgsprovidercountcalcevent.cpp <==
/***************************************************************************
      qgsprovidercountcalcevent.cpp  -  Notification that the exact count
                                        of a layer has been calculated.
                             -------------------
    begin                : Feb 1, 2005
    copyright            : (C) 2005 by Brendan Morley
    email                : morb at ozemail dot com dot au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsprovidercountcalcevent.cpp 4502 2006-01-08 01:18:20Z timlinux $ */

#include "qgsprovidercountcalcevent.h"
//Added by qt3to4:
#include <QCustomEvent>

QgsProviderCountCalcEvent::QgsProviderCountCalcEvent( long numberFeatures )
    : QCustomEvent( QGis::ProviderCountCalcEvent ),
      n( numberFeatures )
{
  // NO-OP
}


long QgsProviderCountCalcEvent::numberFeatures() const
{
  return n;
}

==> qgis_1.3.0.tar.gz: qgis-1.3.0/src/core/qgsprovidercountcalcevent.cpp <==
/***************************************************************************
      qgsprovidercountcalcevent.cpp  -  Notification that the exact count
                                        of a layer has been calculated.
                             -------------------
    begin                : Feb 1, 2005
    copyright            : (C) 2005 by Brendan Morley
    email                : morb at ozemail dot com dot au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsprovidercountcalcevent.cpp 9538 2008-10-24 22:12:40Z timlinux $ */

#include "qgsprovidercountcalcevent.h"
#include "qgis.h"

QgsProviderCountCalcEvent::QgsProviderCountCalcEvent( long featuresCounted )
    : QEvent( static_cast<QEvent::Type>( QGis::ProviderCountCalcEvent ) ),
    n( featuresCounted )
{
  // NO-OP
}


long QgsProviderCountCalcEvent::featuresCounted() const
{
  return n;
}
